@@ -13,16 +13,22 @@
 # limitations under the License.
 
 from __future__ import with_statement
+from _weakref import ref
 import calendar
+from collections import OrderedDict
+from collections.abc import Mapping
 import datetime
 from functools import total_ordering
-import logging
 from itertools import chain
+import keyword
+import logging
+import pickle
 import random
 import re
-import six
-import uuid
+import socket
 import sys
+import time
+import uuid
 
 _HAS_GEOMET = True
 try:
@@ -212,147 +218,6 @@ def _resolve_contact_points_to_string_map(contact_points):
     )
 
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    # OrderedDict from Python 2.7+
-
-    # Copyright (c) 2009 Raymond Hettinger
-    #
-    # Permission is hereby granted, free of charge, to any person
-    # obtaining a copy of this software and associated documentation files
-    # (the "Software"), to deal in the Software without restriction,
-    # including without limitation the rights to use, copy, modify, merge,
-    # publish, distribute, sublicense, and/or sell copies of the Software,
-    # and to permit persons to whom the Software is furnished to do so,
-    # subject to the following conditions:
-    #
-    #     The above copyright notice and this permission notice shall be
-    #     included in all copies or substantial portions of the Software.
-    #
-    #     THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-    #     EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-    #     OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-    #     NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-    #     HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-    #     WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-    #     FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-    #     OTHER DEALINGS IN THE SOFTWARE.
-    from UserDict import DictMixin
-
-    class OrderedDict(dict, DictMixin):  # noqa
-        """ A dictionary which maintains the insertion order of keys. """
-
-        def __init__(self, *args, **kwds):
-            """ A dictionary which maintains the insertion order of keys. """
-
-            if len(args) > 1:
-                raise TypeError('expected at most 1 arguments, got %d' % len(args))
-            try:
-                self.__end
-            except AttributeError:
-                self.clear()
-            self.update(*args, **kwds)
-
-        def clear(self):
-            self.__end = end = []
-            end += [None, end, end]         # sentinel node for doubly linked list
-            self.__map = {}                 # key --> [key, prev, next]
-            dict.clear(self)
-
-        def __setitem__(self, key, value):
-            if key not in self:
-                end = self.__end
-                curr = end[1]
-                curr[2] = end[1] = self.__map[key] = [key, curr, end]
-            dict.__setitem__(self, key, value)
-
-        def __delitem__(self, key):
-            dict.__delitem__(self, key)
-            key, prev, next = self.__map.pop(key)
-            prev[2] = next
-            next[1] = prev
-
-        def __iter__(self):
-            end = self.__end
-            curr = end[2]
-            while curr is not end:
-                yield curr[0]
-                curr = curr[2]
-
-        def __reversed__(self):
-            end = self.__end
-            curr = end[1]
-            while curr is not end:
-                yield curr[0]
-                curr = curr[1]
-
-        def popitem(self, last=True):
-            if not self:
-                raise KeyError('dictionary is empty')
-            if last:
-                key = next(reversed(self))
-            else:
-                key = next(iter(self))
-            value = self.pop(key)
-            return key, value
-
-        def __reduce__(self):
-            items = [[k, self[k]] for k in self]
-            tmp = self.__map, self.__end
-            del self.__map, self.__end
-            inst_dict = vars(self).copy()
-            self.__map, self.__end = tmp
-            if inst_dict:
-                return (self.__class__, (items,), inst_dict)
-            return self.__class__, (items,)
-
-        def keys(self):
-            return list(self)
-
-        setdefault = DictMixin.setdefault
-        update = DictMixin.update
-        pop = DictMixin.pop
-        values = DictMixin.values
-        items = DictMixin.items
-        iterkeys = DictMixin.iterkeys
-        itervalues = DictMixin.itervalues
-        iteritems = DictMixin.iteritems
-
-        def __repr__(self):
-            if not self:
-                return '%s()' % (self.__class__.__name__,)
-            return '%s(%r)' % (self.__class__.__name__, self.items())
-
-        def copy(self):
-            return self.__class__(self)
-
-        @classmethod
-        def fromkeys(cls, iterable, value=None):
-            d = cls()
-            for key in iterable:
-                d[key] = value
-            return d
-
-        def __eq__(self, other):
-            if isinstance(other, OrderedDict):
-                if len(self) != len(other):
-                    return False
-                for p, q in zip(self.items(), other.items()):
-                    if p != q:
-                        return False
-                return True
-            return dict.__eq__(self, other)
-
-        def __ne__(self, other):
-            return not self == other
-
-
-# WeakSet from Python 2.7+ (https://code.google.com/p/weakrefset)
-
-from _weakref import ref
-
-
 class _IterationGuard(object):
     # This context manager registers itself in the current iterators of the
     # weak container, such as to delay all removals until the context manager
@@ -789,15 +654,11 @@ class SortedSet(object):
 sortedset = SortedSet  # backwards-compatibility
 
 
-from cassandra.compat import Mapping
-from six.moves import cPickle
-
-
 class OrderedMap(Mapping):
     '''
     An ordered map that accepts non-hashable types for keys. It also maintains the
     insertion order of items, behaving as OrderedDict in that regard. These maps
-    are constructed and read just as normal mapping types, exept that they may
+    are constructed and read just as normal mapping types, except that they may
     contain arbitrary collections and other non-hashable items as keys::
 
         >>> od = OrderedMap([({'one': 1, 'two': 2}, 'value'),
@@ -835,7 +696,7 @@ class OrderedMap(Mapping):
                 for k, v in e:
                     self._insert(k, v)
 
-        for k, v in six.iteritems(kwargs):
+        for k, v in kwargs.items():
             self._insert(k, v)
 
     def _insert(self, key, value):
@@ -901,7 +762,7 @@ class OrderedMap(Mapping):
             raise KeyError()
 
     def _serialize_key(self, key):
-        return cPickle.dumps(key)
+        return pickle.dumps(key)
 
 
 class OrderedMapSerializedKey(OrderedMap):
@@ -919,13 +780,6 @@ class OrderedMapSerializedKey(OrderedMap):
         return self.cass_key_type.serialize(key, self.protocol_version)
 
 
-import datetime
-import time
-
-if six.PY3:
-    long = int
-
-
 @total_ordering
 class Time(object):
     '''
@@ -951,11 +805,11 @@ class Time(object):
         - datetime.time: built-in time
         - string_type: a string time of the form "HH:MM:SS[.mmmuuunnn]"
         """
-        if isinstance(value, six.integer_types):
+        if isinstance(value, int):
             self._from_timestamp(value)
         elif isinstance(value, datetime.time):
             self._from_time(value)
-        elif isinstance(value, six.string_types):
+        elif isinstance(value, str):
             self._from_timestring(value)
         else:
             raise TypeError('Time arguments must be a whole number, datetime.time, or string')
@@ -1031,7 +885,7 @@ class Time(object):
         if isinstance(other, Time):
             return self.nanosecond_time == other.nanosecond_time
 
-        if isinstance(other, six.integer_types):
+        if isinstance(other, int):
             return self.nanosecond_time == other
 
         return self.nanosecond_time % Time.MICRO == 0 and \
@@ -1080,11 +934,11 @@ class Date(object):
         - datetime.date: built-in date
         - string_type: a string time of the form "yyyy-mm-dd"
         """
-        if isinstance(value, six.integer_types):
+        if isinstance(value, int):
             self.days_from_epoch = value
         elif isinstance(value, (datetime.date, datetime.datetime)):
             self._from_timetuple(value.timetuple())
-        elif isinstance(value, six.string_types):
+        elif isinstance(value, str):
             self._from_datestring(value)
         else:
             raise TypeError('Date arguments must be a whole number, datetime.date, or string')
@@ -1124,7 +978,7 @@ class Date(object):
         if isinstance(other, Date):
             return self.days_from_epoch == other.days_from_epoch
 
-        if isinstance(other, six.integer_types):
+        if isinstance(other, int):
             return self.days_from_epoch == other
 
         try:
@@ -1151,97 +1005,9 @@ class Date(object):
             # If we overflow datetime.[MIN|MAX]
             return str(self.days_from_epoch)
 
-import socket
-if hasattr(socket, 'inet_pton'):
-    inet_pton = socket.inet_pton
-    inet_ntop = socket.inet_ntop
-else:
-    """
-    Windows doesn't have socket.inet_pton and socket.inet_ntop until Python 3.4
-    This is an alternative impl using ctypes, based on this win_inet_pton project:
-    https://github.com/hickeroar/win_inet_pton
-    """
-    import ctypes
 
-    class sockaddr(ctypes.Structure):
-        """
-        Shared struct for ipv4 and ipv6.
-
-        https://msdn.microsoft.com/en-us/library/windows/desktop/ms740496(v=vs.85).aspx
-
-        ``__pad1`` always covers the port.
-
-        When being used for ``sockaddr_in6``, ``ipv4_addr`` actually covers ``sin6_flowinfo``, resulting
-        in proper alignment for ``ipv6_addr``.
-        """
-        _fields_ = [("sa_family", ctypes.c_short),
-                    ("__pad1", ctypes.c_ushort),
-                    ("ipv4_addr", ctypes.c_byte * 4),
-                    ("ipv6_addr", ctypes.c_byte * 16),
-                    ("__pad2", ctypes.c_ulong)]
-
-    if hasattr(ctypes, 'windll'):
-        WSAStringToAddressA = ctypes.windll.ws2_32.WSAStringToAddressA
-        WSAAddressToStringA = ctypes.windll.ws2_32.WSAAddressToStringA
-    else:
-        def not_windows(*args):
-            raise OSError("IPv6 addresses cannot be handled on Windows. "
-                            "Missing ctypes.windll")
-        WSAStringToAddressA = not_windows
-        WSAAddressToStringA = not_windows
-
-    def inet_pton(address_family, ip_string):
-        if address_family == socket.AF_INET:
-            return socket.inet_aton(ip_string)
-
-        addr = sockaddr()
-        addr.sa_family = address_family
-        addr_size = ctypes.c_int(ctypes.sizeof(addr))
-
-        if WSAStringToAddressA(
-                ip_string,
-                address_family,
-                None,
-                ctypes.byref(addr),
-                ctypes.byref(addr_size)
-        ) != 0:
-            raise socket.error(ctypes.FormatError())
-
-        if address_family == socket.AF_INET6:
-            return ctypes.string_at(addr.ipv6_addr, 16)
-
-        raise socket.error('unknown address family')
-
-    def inet_ntop(address_family, packed_ip):
-        if address_family == socket.AF_INET:
-            return socket.inet_ntoa(packed_ip)
-
-        addr = sockaddr()
-        addr.sa_family = address_family
-        addr_size = ctypes.c_int(ctypes.sizeof(addr))
-        ip_string = ctypes.create_string_buffer(128)
-        ip_string_size = ctypes.c_int(ctypes.sizeof(ip_string))
-
-        if address_family == socket.AF_INET6:
-            if len(packed_ip) != ctypes.sizeof(addr.ipv6_addr):
-                raise socket.error('packed IP wrong length for inet_ntoa')
-            ctypes.memmove(addr.ipv6_addr, packed_ip, 16)
-        else:
-            raise socket.error('unknown address family')
-
-        if WSAAddressToStringA(
-                ctypes.byref(addr),
-                addr_size,
-                None,
-                ip_string,
-                ctypes.byref(ip_string_size)
-        ) != 0:
-            raise socket.error(ctypes.FormatError())
-
-        return ip_string[:ip_string_size.value - 1]
-
-
-import keyword
+inet_pton = socket.inet_pton
+inet_ntop = socket.inet_ntop
 
 
 # similar to collections.namedtuple, reproduced here because Python 2.6 did not have the rename logic
@@ -1688,7 +1454,7 @@ class DateRangeBound(object):
 
         if value is None:
             milliseconds = None
-        elif isinstance(value, six.integer_types):
+        elif isinstance(value, int):
             milliseconds = value
         elif isinstance(value, datetime.datetime):
             value = value.replace(
@@ -1956,12 +1722,10 @@ class Version(object):
 
         try:
             self.major = int(parts.pop())
-        except ValueError:
-            six.reraise(
-                ValueError,
-                ValueError("Couldn't parse version {}. Version should start with a number".format(version)),
-                sys.exc_info()[2]
-            )
+        except ValueError as e:
+            raise ValueError(
+                "Couldn't parse version {}. Version should start with a number".format(version))\
+                .with_traceback(e.__traceback__)
         try:
             self.minor = int(parts.pop()) if parts else 0
             self.patch = int(parts.pop()) if parts else 0
@@ -1994,8 +1758,8 @@ class Version(object):
 
     @staticmethod
     def _compare_version_part(version, other_version, cmp):
-        if not (isinstance(version, six.integer_types) and
-                isinstance(other_version, six.integer_types)):
+        if not (isinstance(version, int) and
+                isinstance(other_version, int)):
             version = str(version)
             other_version = str(other_version)
 
