@@ -14,31 +14,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals
-
-import binascii
 import calendar
 import datetime
 import math
 import os
 import re
 import sys
-import platform
-
-from six import ensure_text
+import wcwidth
 
 from collections import defaultdict
 
 from cassandra.cqltypes import EMPTY
 from cassandra.util import datetime_from_timestamp
-from . import wcwidth
 from .displaying import colorme, get_str, FormattedValue, DEFAULT_VALUE_COLORS, NO_COLOR_MAP
 from .util import UTC
 
-is_win = platform.system() == 'Windows'
-
-unicode_controlchars_re = re.compile(r'[\x00-\x31\x7f-\xa0]')
-controlchars_re = re.compile(r'[\x00-\x31\x7f-\xff]')
+unicode_controlchars_re = re.compile(r'[\x00-\x1f\x7f-\xa0]')
+controlchars_re = re.compile(r'[\x00-\x1f\x7f-\xff]')
 
 
 def _show_control_chars(match):
@@ -126,7 +118,7 @@ class DateTimeFormat:
         self.milliseconds_only = milliseconds_only  # the microseconds part, .NNNNNN, wil be rounded to .NNN
 
 
-class CqlType(object):
+class CqlType:
     """
     A class for converting a string into a cql type name that can match a formatter
     and a list of its sub-types, if any.
@@ -157,8 +149,8 @@ class CqlType(object):
     def parse(self, typestring, ksmeta):
         """
         Parse the typestring by looking at this pattern: *<*>. If there is no match then the type
-        is either a simple type or a user type, otherwise it must be a composite type
-        for which we need to look-up the sub-types. For user types the sub types can be extracted
+        is either a simple type or a user type, otherwise it must be a composite type or a vector type,
+        for which we need to look up the subtypes. For user types the subtypes can be extracted
         from the keyspace metadata.
         """
         while True:
@@ -175,8 +167,15 @@ class CqlType(object):
                     typestring = m.group(2)
                     continue
 
-                name = m.group(1)  # a composite type, parse sub types
-                return name, self.parse_sub_types(m.group(2), ksmeta), self._get_formatter(name)
+                name = m.group(1)  # a composite or vector type, parse subtypes
+                try:
+                    # Vector types are parameterized as name<type,size> so add custom handling for that here
+                    type_args = m.group(2).split(',')
+                    vector_type = CqlType(type_args[0])
+                    vector_size = int(type_args[1])
+                    return name, [vector_type for _ in range(vector_size)], self._get_formatter(name)
+                except (ValueError, IndexError):
+                    return name, self.parse_sub_types(m.group(2), ksmeta), self._get_formatter(name)
 
     @staticmethod
     def _get_formatter(name):
@@ -208,7 +207,7 @@ class CqlType(object):
 
 
 def format_value_default(val, colormap, **_):
-    val = ensure_text(str(val))
+    val = str(val)
     escapedval = val.replace('\\', '\\\\')
     bval = controlchars_re.sub(_show_control_chars, escapedval)
     return bval if colormap is NO_COLOR_MAP else color_text(bval, colormap)
@@ -240,7 +239,7 @@ def formatter_for(typname):
     return registrator
 
 
-class BlobType(object):
+class BlobType:
     def __init__(self, val):
         self.val = val
 
@@ -250,7 +249,7 @@ class BlobType(object):
 
 @formatter_for('BlobType')
 def format_value_blob(val, colormap, **_):
-    bval = ensure_text('0x') + ensure_text(binascii.hexlify(val))
+    bval = '0x' + val.hex()
     return colorme(bval, colormap, 'blob')
 
 
@@ -260,7 +259,7 @@ formatter_for('blob')(format_value_blob)
 
 
 def format_python_formatted_type(val, colormap, color, quote=False):
-    bval = ensure_text(str(val))
+    bval = str(val)
     if quote:
         bval = "'%s'" % bval
     return colorme(bval, colormap, color)
@@ -330,23 +329,13 @@ formatter_for('double')(format_floating_point_type)
 def format_integer_type(val, colormap, thousands_sep=None, **_):
     # base-10 only for now; support others?
     bval = format_integer_with_thousands_sep(val, thousands_sep) if thousands_sep else str(val)
-    bval = ensure_text(bval)
+    bval = str(bval)
     return colorme(bval, colormap, 'int')
 
 
-# We can get rid of this in cassandra-2.2
-if sys.version_info >= (2, 7):
-    def format_integer_with_thousands_sep(val, thousands_sep=','):
-        return "{:,.0f}".format(val).replace(',', thousands_sep)
-else:
-    def format_integer_with_thousands_sep(val, thousands_sep=','):
-        if val < 0:
-            return '-' + format_integer_with_thousands_sep(-val, thousands_sep)
-        result = ''
-        while val >= 1000:
-            val, r = divmod(val, 1000)
-            result = "%s%03d%s" % (thousands_sep, r, result)
-        return "%d%s" % (val, result)
+def format_integer_with_thousands_sep(val, thousands_sep=','):
+    return "{:,.0f}".format(val).replace(',', thousands_sep)
+
 
 formatter_for('long')(format_integer_type)
 formatter_for('int')(format_integer_type)
@@ -365,7 +354,7 @@ def format_value_timestamp(val, colormap, date_time_format, quote=False, **_):
         if date_time_format.milliseconds_only:
             bval = round_microseconds(bval)
     else:
-        bval = ensure_text(str(val))
+        bval = str(val)
 
     if quote:
         bval = "'%s'" % bval
@@ -448,7 +437,7 @@ def append(builder, dividend, divisor, unit):
     if dividend == 0 or dividend < divisor:
         return dividend
 
-    builder.append(str(dividend / divisor))
+    builder.append(str(dividend // divisor))
     builder.append(unit)
     return dividend % divisor
 
